# Simplify Downloading Files From Telegram For PyTelegramBotAPI

This is my first package. I hope - not last!

You can use this package for downloading files from Telegram.

### Install

You can pip for it

pip install Simplify_downloading_files_TG

### How to use?

This package has 2 procedure(getphoto and getdocument).

#### GETPHOTO(token, bot, message, filename, *dir)

This procedure request 4 required parameters and 1 not required.

##### Token is token for your telegram bot

##### Bot is your class instance from telebot module

##### Message is message with photo

##### Filename is filename from saving photo

##### And *dir is if you need to save in another directory

#### and GETDOCUMENT(token, bot, message, filename, *dir) has same parameters
